const { promisify } = require("util")
const figlet = promisify(require("figlet")) // 展示字符画
const clear = require("clear") // 清屏
const chalk = require("chalk") // 给log日志加上颜色
const { clone } = require("./download")

// 封装spawn，将子进程的输出流对接到主进程上，这样在主进程的控制台可以看到日志
// 可以直接用 child-process 暴露的 spawn 执行 npm install,但是这样在主进程控制台看不到日志信息
const spawn = async (...args) => {
  const { spawn } = require("child_process")
  const options = args[args.length - 1]

  if (process.platform === "win32") {
    // 设置 shell 选项为 true 以隐式地调用 cmd
    options.shell = true
  }

  // 1. 封装成promise风格，便于之后使用async await语法
  // 2. 将子进程log流对接到主进程中去
  return new Promise((resolve) => {
    const proc = spawn(...args)
    proc.stdout.pipe(process.stdout)
    proc.stderr.pipe(process.stderr)

    // 检测命令执行完毕
    proc.on("close", () => {
      resolve()
    })
  })
}

// 封装log，输出log为绿色
const log = (content) => console.log(chalk.green(content))

module.exports = async (name) => {
  // 打印欢迎画面
  clear() //  清屏
  const data = await figlet("KKB Welcome")
  log(data)

  // 创建项目
  log(`🚀创建项目:` + name)
  // 克隆代码
  await clone("github:su37josephxia/vue-template", name)

  log("安装依赖")
  await spawn("npm", ["install"], { cwd: `./${name}` }) //{ cwd: `./${name}` } 指定命令运行的目录
  log(`
  👌安装完成：
  To get Start:
  ===========================
      cd ${name}
      npm run serve
  ===========================
              `)

  // 打开链接，并启动服务
  const open = require("open")
  open("http://localhost:8080")
  await spawn("npm", ["run", "serve"], { cwd: `./${name}` })
}
