const fs = require("fs")
// js语义模板库，模板引擎，用来解析hbs模板文件
const handlebars = require("handlebars")
const chalk = require("chalk")

module.exports = async () => {
  // 获取页面列表
  const list = fs
    .readdirSync("./src/views")
    .filter((v) => v !== "Home.vue")
    .map((v) => ({
      name: v.replace(".vue", "").toLowerCase(),
      file: v,
    }))

  // 生成路由信息
  compile({ list }, "./src/router.js", "./template/router.js.hbs")

  // 生成菜单
  compile({ list }, "./src/App.vue", "./template/App.vue.hbs")

  /**
   * 根据模板templatePath和传入数据meta在对应文件下filePath生成对应的内容
   * @param {*} meta
   * @param {*} filePath
   * @param {*} templatePath
   */
  function compile(meta, filePath, templatePath) {
    if (fs.existsSync(templatePath)) {
      // 读取模板内容
      const content = fs.readFileSync(templatePath).toString()
      // 使用模板引擎组装文件内容
      const reslut = handlebars.compile(content)(meta)
      // 写入文件内容
      fs.writeFileSync(filePath, reslut)
    }
    console.log(chalk.red(`🚀${filePath} 创建成功`))
  }
}
